from exceptions import ArgumentMissing


class GestionSportsPayloadBuilder:
    def __init__(self):
        self._login = None
        self._password = None
        self._club_id = None
        self._date = None
        self._time = None
        self._sport_id = None
        self._court_id = None

    def login(self, login: str):
        self._login = login
        return self

    def password(self, password: str):
        self._password = password
        return self

    def club_id(self, club_id: str):
        self._club_id = club_id
        return self

    def date(self, date: str):
        self._date = date
        return self

    def time(self, time: str):
        self._time = time
        return self

    def sport_id(self, sport_id: int):
        self._sport_id = sport_id
        return self

    def court_id(self, court_id: int):
        self._court_id = court_id
        return self

    def build_login_payload(self):
        if self._login is None:
            raise ArgumentMissing("Login not provided")
        if self.password is None:
            raise ArgumentMissing("Password not provided")
        if self._club_id is None:
            raise ArgumentMissing("Club ID not provided")

        return (
            f"ajax=connexionUser&id_club={self._club_id}&email={self._login}&form_ajax=1&pass={self._password}&compte"
            f"=user&playeridonesignal=0&identifiant=identifiant&externCo=true"
        ).encode("utf-8")

    def build_booking_payload(self):
        if self._date is None:
            raise ArgumentMissing("Date not provided")
        if self._time is None:
            raise ArgumentMissing("Time not provided")
        if self._sport_id is None:
            raise ArgumentMissing("Sport ID not provided")
        if self._court_id is None:
            raise ArgumentMissing("Court ID not provided")

        return (
            f"ajax=addResa&date={self._date}&hour={self._time}&duration=90&partners=null|null|null"
            f"&paiement=facultatif&idSport={self._sport_id}&creaPartie=false&idCourt={self._court_id}"
            f"&pay=false&token=undefined&totalPrice=44&saveCard=0&foodNumber=0"
        ).encode("utf-8")
